@@ -31,6 +31,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KLocalizedString>
 #include <KJobUiDelegate>
 
+// Exiv2
+#include <exiv2/exiv2.hpp>
+
 // Local
 #include "documentjob.h"
 #include "emptydocumentimpl.h"
@@ -240,16 +243,16 @@ void Document::switchToImpl(AbstractDocumentImpl* impl)
     }
     d->mImpl = impl;
 
-    connect(d->mImpl, SIGNAL(metaInfoLoaded()),
-            this, SLOT(emitMetaInfoLoaded()));
-    connect(d->mImpl, SIGNAL(loaded()),
-            this, SLOT(emitLoaded()));
-    connect(d->mImpl, SIGNAL(loadingFailed()),
-            this, SLOT(emitLoadingFailed()));
-    connect(d->mImpl, SIGNAL(imageRectUpdated(QRect)),
-            this, SIGNAL(imageRectUpdated(QRect)));
-    connect(d->mImpl, SIGNAL(isAnimatedUpdated()),
-            this, SIGNAL(isAnimatedUpdated()));
+    connect(d->mImpl, &AbstractDocumentImpl::metaInfoLoaded,
+            this, &Document::emitMetaInfoLoaded);
+    connect(d->mImpl, &AbstractDocumentImpl::loaded,
+            this, &Document::emitLoaded);
+    connect(d->mImpl, &AbstractDocumentImpl::loadingFailed,
+            this, &Document::emitLoadingFailed);
+    connect(d->mImpl, &AbstractDocumentImpl::imageRectUpdated,
+            this, &Document::imageRectUpdated);
+    connect(d->mImpl, &AbstractDocumentImpl::isAnimatedUpdated,
+            this, &Document::isAnimatedUpdated);
     d->mImpl->init();
 }
 
@@ -388,9 +391,9 @@ AbstractDocumentEditor* Document::editor()
     return d->mImpl->editor();
 }
 
-void Document::setExiv2Image(Exiv2::Image::AutoPtr image)
+void Document::setExiv2Image(std::unique_ptr<Exiv2::Image> image)
 {
-    d->mExiv2Image = image;
+    d->mExiv2Image = std::move(image);
     d->mImageMetaInfoModel.setExiv2Image(d->mExiv2Image.get());
     emit metaInfoUpdated();
 }
@@ -559,7 +562,7 @@ QSvgRenderer* Document::svgRenderer() const
     return d->mImpl->svgRenderer();
 }
 
-void Document::setCmsProfile(Cms::Profile::Ptr ptr)
+void Document::setCmsProfile(const Cms::Profile::Ptr &ptr)
 {
     d->mCmsProfile = ptr;
 }
