@@ -24,6 +24,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 // STL
 #include <memory>
 
+// Exiv2
+#include <exiv2/exiv2.hpp>
+
 // Qt
 #include <QBuffer>
 #include <QByteArray>
@@ -100,7 +103,7 @@ struct LoadingDocumentImplPrivate
     QByteArray mData;
     QByteArray mFormat;
     QSize mImageSize;
-    Exiv2::Image::AutoPtr mExiv2Image;
+    std::unique_ptr<Exiv2::Image> mExiv2Image;
     std::unique_ptr<JpegContent> mJpegContent;
     QImage mImage;
     Cms::Profile::Ptr mCmsProfile;
@@ -358,11 +361,11 @@ LoadingDocumentImpl::LoadingDocumentImpl(Document* document)
     d->mDownSampledImageLoaded = false;
     d->mImageDataInvertedZoom = 0;
 
-    connect(&d->mMetaInfoFutureWatcher, SIGNAL(finished()),
-            SLOT(slotMetaInfoLoaded()));
+    connect(&d->mMetaInfoFutureWatcher, &QFutureWatcherBase::finished,
+            this, &LoadingDocumentImpl::slotMetaInfoLoaded);
 
-    connect(&d->mImageDataFutureWatcher, SIGNAL(finished()),
-            SLOT(slotImageLoaded()));
+    connect(&d->mImageDataFutureWatcher, &QFutureWatcherBase::finished,
+            this, &LoadingDocumentImpl::slotImageLoaded);
 }
 
 LoadingDocumentImpl::~LoadingDocumentImpl()
@@ -403,10 +406,10 @@ void LoadingDocumentImpl::init()
     } else {
         // Transfer file via KIO
         d->mTransferJob = KIO::get(document()->url(), KIO::NoReload, KIO::HideProgressInfo);
-        connect(d->mTransferJob, SIGNAL(data(KIO::Job*,QByteArray)),
-                SLOT(slotDataReceived(KIO::Job*,QByteArray)));
-        connect(d->mTransferJob, SIGNAL(result(KJob*)),
-                SLOT(slotTransferFinished(KJob*)));
+        connect(d->mTransferJob.data(), &KIO::TransferJob::data,
+                this, &LoadingDocumentImpl::slotDataReceived);
+        connect(d->mTransferJob.data(), &KJob::result,
+                this, &LoadingDocumentImpl::slotTransferFinished);
         d->mTransferJob->start();
     }
 }
@@ -486,7 +489,7 @@ void LoadingDocumentImpl::slotMetaInfoLoaded()
 
     setDocumentFormat(d->mFormat);
     setDocumentImageSize(d->mImageSize);
-    setDocumentExiv2Image(d->mExiv2Image);
+    setDocumentExiv2Image(std::move(d->mExiv2Image));
     setDocumentCmsProfile(d->mCmsProfile);
 
     d->mMetaInfoLoaded = true;
